@@ -31,6 +31,8 @@
 #include <bmon/input.h>
 #include <bmon/utils.h>
 
+#ifndef SYS_BSD
+
 static int c_notc = 0;
 static struct element_group *grp;
 static struct bmon_module netlink_ops;
@@ -58,7 +60,7 @@ static struct attr_map link_attrs[] = {
 	.name		= "packets",
 	.type		= ATTR_TYPE_COUNTER,
 	.unit		= UNIT_NUMBER,
-	.description	= "Packtes",
+	.description	= "Packets",
 	.rxid		= RTNL_LINK_RX_PACKETS,
 	.txid		= RTNL_LINK_TX_PACKETS,
 },
@@ -772,7 +774,7 @@ static void netlink_shutdown(void)
 
 static int netlink_do_init(void)
 {
-	int err, i;
+	int err;
 
 	if (!(sock = nl_socket_alloc())) {
 		fprintf(stderr, "Unable to allocate netlink socket\n");
@@ -866,3 +868,4 @@ static void __init netlink_init(void)
 {
 	input_register(&netlink_ops);
 }
+#endif
